## Color Fonts

Glyphs offers a streamlined workflow for creating four types of color fonts: classic layer fonts, Microsoft-style `CPAL` and `COLR` OpenType tables, the Apple-style `sbix` OpenType table, and the Mozilla/Adobe-style `SVG` table.